@@ -682,7 +682,7 @@ class HDF5Reader:
         self.f.close()
 
     # ----------------------------------------------------------------------
-    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, **kwargs) -> mne.EpochsArray:
+    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, preprocess=None, **kwargs) -> mne.EpochsArray:
         """Create an `EpochsArray` object with the `MNE` library.
 
         This method auto crop the data in regard to markers also will drop
@@ -765,7 +765,12 @@ class HDF5Reader:
         event_id = {mk: self.classes_indexes[mk] for mk in markers}
         events = [[i, 1, event_id[cls]] for i, cls in enumerate(classes)]
 
-        return mne.EpochsArray(np.array(data), info, events=events, tmin=tmin, event_id=event_id, **kwargs)
+        if preprocess:
+            data = preprocess(np.array(data))
+        else:
+            data = np.array(data)
+
+        return mne.EpochsArray(data, info, events=events, tmin=tmin, event_id=event_id, **kwargs)
 
     # ----------------------------------------------------------------------
     def to_edf(self, filename: str) -> None:
